==> valentina_0.7.52~dfsg.orig.tar.xz: valentina-v0.7.52/src/libs/vmisc/dialogs/dialogselectlanguage.cpp <==
/************************************************************************
 **
 **  @file   dialogselectlanguage.cpp
 **  @author Roman Telezhynskyi <dismine(at)gmail.com>
 **  @date   19 10, 2021
 **
 **  @brief
 **  @copyright
 **  This source code is part of the Valentina project, a pattern making
 **  program, whose allow create and modeling patterns of clothing.
 **  Copyright (C) 2021 Valentina project
 **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
 **
 **  Valentina is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
 **  Valentina is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with Valentina.  If not, see <http://www.gnu.org/licenses/>.
 **
 *************************************************************************/
#include "dialogselectlanguage.h"
#include "ui_dialogselectlanguage.h"
#include "../vmisc/def.h"

//---------------------------------------------------------------------------------------------------------------------
DialogSelectLanguage::DialogSelectLanguage(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::DialogSelectLanguage)
{
    ui->setupUi(this);

    InitLanguages(ui->comboBoxLanguage);
}

//---------------------------------------------------------------------------------------------------------------------
DialogSelectLanguage::~DialogSelectLanguage()
{
    delete ui;
}

//---------------------------------------------------------------------------------------------------------------------
QString DialogSelectLanguage::Locale() const
{
    return qvariant_cast<QString>(ui->comboBoxLanguage->currentData());
}

==> valentina_1.0.0~dfsg.orig.tar.xz: valentina-v1.0.0/src/libs/vmisc/dialogs/dialogselectlanguage.cpp <==
/************************************************************************
 **
 **  @file   dialogselectlanguage.cpp
 **  @author Roman Telezhynskyi <dismine(at)gmail.com>
 **  @date   19 10, 2021
 **
 **  @brief
 **  @copyright
 **  This source code is part of the Valentina project, a pattern making
 **  program, whose allow create and modeling patterns of clothing.
 **  Copyright (C) 2021 Valentina project
 **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
 **
 **  Valentina is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
 **  Valentina is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with Valentina.  If not, see <http://www.gnu.org/licenses/>.
 **
 *************************************************************************/
#include "dialogselectlanguage.h"
#include "ui_dialogselectlanguage.h"
#include "../def.h"

//---------------------------------------------------------------------------------------------------------------------
DialogSelectLanguage::DialogSelectLanguage(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::DialogSelectLanguage)
{
    ui->setupUi(this);

    InitLanguages(ui->comboBoxLanguage);
}

//---------------------------------------------------------------------------------------------------------------------
DialogSelectLanguage::~DialogSelectLanguage()
{
    delete ui;
}

//---------------------------------------------------------------------------------------------------------------------
auto DialogSelectLanguage::Locale() const -> QString
{
    return qvariant_cast<QString>(ui->comboBoxLanguage->currentData());
}
